@@ -1,4 +1,5 @@
 #!/usr/bin/env python3
+# PYTHON_ARGCOMPLETE_OK
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import gettext
@@ -9,9 +10,14 @@ from argparse import ArgumentParser
 import pycountry
 
 try:
-    from progressbar import ProgressBar, Bar, ETA, SimpleProgress
+    import argcomplete
 except ImportError:
-    ProgressBar = None
+    argcomplete = None
+
+try:
+    from tqdm import tqdm
+except ImportError:
+    tqdm = None
 
 try:
     from proteus import Model, config
@@ -20,13 +26,11 @@ except ImportError:
     sys.exit("proteus must be installed to use %s" % prog)
 
 
-def _progress(iterable):
-    if ProgressBar:
-        pbar = ProgressBar(
-            widgets=[SimpleProgress(), Bar(), ETA()])
+def _progress(iterable, **kwargs):
+    if tqdm:
+        return tqdm(iterable, disable=None, **kwargs)
     else:
-        pbar = iter
-    return pbar(iterable)
+        return iterable
 
 
 def _get_language_codes():
@@ -37,11 +41,8 @@ def _get_language_codes():
 
 
 def _remove_forbidden_chars(name):
-    from trytond.model.fields import Char
-    for c in Char.forbidden_chars:
-        if c in name:
-            name.replace(c, ' ')
-    return name.strip()
+    from trytond.tools import remove_forbidden_chars
+    return remove_forbidden_chars(name)
 
 
 def get_currencies():
@@ -59,11 +60,9 @@ def update_currencies(currencies):
         if code in currencies:
             record = currencies[code]
         else:
-            record = Currency(code=code, symbol=None)
+            record = Currency(code=code)
         record.name = _remove_forbidden_chars(currency.name)
         record.numeric_code = currency.numeric
-        if not record.symbol:
-            record.symbol = currency.alpha_3
         records.append(record)
 
     Currency.save(records)
@@ -108,6 +107,8 @@ def run():
     parser.add_argument('-d', '--database', dest='database', required=True)
     parser.add_argument('-c', '--config', dest='config_file',
         help='the trytond config file')
+    if argcomplete:
+        argcomplete.autocomplete(parser)
 
     args = parser.parse_args()
     main(args.database, args.config_file)
